#!/usr/bin/env python

"""
Point2Play Source Code
Copyright (c) 2004 by TransGaming Technologies, Inc.
All rights reserved
Redistribution of Point2Play is forbidden without the expressed written 
permission of TransGaming Technologies Inc.

"""

import pygtk
pygtk.require('2.0')
import gtk, gobject
import gtk.glade
import log
import os, re
import gui_utils, system_detection, p2p_gui

# If Point2Play is being launched by the packaged launch script, then it needs to be able
# to be launched from anywhere.  In this case, P2PPATH will already be set, and we can use
# that as a path to locate our files.

p2ppath = ""
running_from_cvs = False
if os.environ.has_key('P2PPATH'):
    p2ppath = os.getenv("P2PPATH")
if os.environ.has_key('RUNNING_FROM_CVS'):
    running_from_cvs = os.getenv("RUNNING_FROM_CVS")
GLADE_FILE = "./gui/" + __name__ + ".glade"
if not running_from_cvs and p2ppath:
    GLADE_FILE = p2ppath + "/gui/" + __name__ + ".glade"

class WidgetsWrapper:
    def __init__(self):
        self.widgets = gtk.glade.XML(GLADE_FILE, None, "p2p_localized_msg")

    # Gives us the ability to do: widgets['widget_name'].action()
    def __getitem__(self, key):
        return self.widgets.get_widget(key)

class SystemSettingsDialog:
    def __init__(self, Point2Play, parent):
        self.Point2Play = Point2Play
        self.widgets = WidgetsWrapper()
        self.parent = parent
        self.widgets.widgets.signal_autoconnect(self)
        self.set_system_info(Point2Play.config)

    def ok_cb(self, button):
        gui_utils.save_widget_data(self, system_detection.system_data_widgets_list, self.Point2Play)
        self.widgets["settings"].response(1)

    def cancel_cb(self, button):
        self.widgets["settings"].response(0)

    def autodetect_cb(self, button):
        system_info = system_detection.make_detected_system_info_dictionary()
        self.set_system_info(system_info)
        system_detection.detect_optical_drives(self.Point2Play, force=True)

    def set_system_info(self, dictionary):
        """ Pass either a dictionary with default values given by detect_system_info() or
            a Point2Play config object """

        for w in system_detection.system_data_widgets_list:
            log.logger.info("w " + w + " is " + dictionary[w])
            self.widgets[w].set_text(dictionary[w])


